You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by kr...@apache.org on 2007/03/15 11:51:13 UTC

svn commit: r518577 - in /db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer: RunLangTest.java RunOptimizerTest.java

Author: kristwaa
Date: Thu Mar 15 03:51:10 2007
New Revision: 518577

URL: http://svn.apache.org/viewvc?view=rev&rev=518577
Log:
DERBY-2393: Change the test name from RunLangTest to RunOptimizerTest.

Patch contributed by Manjula Kutty.

Added:
    db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer/RunOptimizerTest.java
      - copied, changed from r518547, db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer/RunLangTest.java
Removed:
    db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer/RunLangTest.java

Copied: db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer/RunOptimizerTest.java (from r518547, db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer/RunLangTest.java)
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer/RunOptimizerTest.java?view=diff&rev=518577&p1=db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer/RunLangTest.java&r1=518547&p2=db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer/RunOptimizerTest.java&r2=518577
==============================================================================
--- db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer/RunLangTest.java (original)
+++ db/derby/code/trunk/java/testing/org/apache/derbyTesting/system/optimizer/RunOptimizerTest.java Thu Mar 15 03:51:10 2007
@@ -1,6 +1,6 @@
 /*
  
- Derby - Class org.apache.derbyTesting.system.langtest.RunLangTest
+ Derby - Class org.apache.derbyTesting.system.optimizer.RunOptimizerTest
  
  Licensed to the Apache Software Foundation (ASF) under one or more
  contributor license agreements.  See the NOTICE file distributed with
@@ -31,11 +31,11 @@
 import org.apache.derbyTesting.system.optimizer.utils.TestViews;
 /**
  * 
  * Class RunLangTest: The main class that runs this test. 
  * 
  * To run the test use:
  * 
- * java org.apache.derbyTesting.system.langtest.RunLangTest -reset|-qlist
+ * java org.apache.derbyTesting.system.optimizer.RunOptimizerTest -reset|-qlist
  * -reset = Reset the database and begin run
  * -qlist = Run only test queries from the 'query.list' file provided
  * No arguments will run all the default test queries, provided via classes
@@ -45,7 +45,7 @@
  * DerbyClient against a Derby Network Server running on port 1527
  */
 
-public class RunLangTest {
+public class RunOptimizerTest {
 
 	public static void main(String[] args) {
 		Connection conn = null;
@@ -122,7 +122,7 @@
 	}
 	private static void printUsage(){
 		System.out.println("Usage:");
-		System.out.println("\njava org.apache.derbyTesting.system.langtest.RunLangTest -reset|-qlist\n");
+		System.out.println("\njava org.apache.derbyTesting.system.optimizer.RunOptimizerTest -reset|-qlist\n");
 		System.out.println("-reset = Reset the database and begin run");
 		System.out.println("-qlist = Run only test queries from the 'query.list' file provided");
 		System.out.println("\nNo arguments will run all the default test queries available in this test case.\n");
@@ -148,4 +148,4 @@
 			System.out.println("\n________________________________________________________________________________________________");
 		}
 	}
-}
\ No newline at end of file
+}
@@ -31,11 +31,11 @@
 /**
  * 
- * Class RunLangTest: The main class that runs this test. 
+ * Class RunOptimizerTest: The main class that runs this test. 
  * 
  * To run the test use: